Learn R Programming

lehdr (version 1.1.4)

grab_crosswalk: Download and load LODES geographic crosswalk into a data frame (tibble)

Description

Download LODES geographic crosswalk

Usage

grab_crosswalk(
  state,
  download_dir = normalizePath(file.path(tools::R_user_dir("lehdr", which = "cache")),
    mustWork = FALSE)
)

Value

a dataframe (tibble) geographic crosswalk at the block level

Arguments

state

US state abbreviation in lower case, can be a vector of states.

download_dir

Directory where lodes table will be downloaded.

Examples

Run this code
# \donttest{
# Download and load current geographic crosswalk for Alaska
alaska_xwalk <- grab_crosswalk("VT")

# Download and load current geographic crosswalk for small states
small_states_xwalk <- grab_crosswalk(c("wy", 'ND', 'SD'))
# }

Run the code above in your browser using DataLab